@@ -49,7 +49,7 @@ extensions = [
     "sphinxcontrib.mermaid",
     # TODO: not working with python 3.10:
     # https://github.com/sphinx-contrib/napoleon/issues/9
-    # "sphinxcontrib.napoleon",  # requires sphinxcontrib-napoleon
+    "sphinxcontrib.napoleon",  # requires sphinxcontrib-napoleon
     "m2r2",  # new md -> rst
     # "sphinx_click",  # requires sphinx-click
 ]
